lang_extensions_ = {
    "py": "cpython-head",
    "cpp": "gcc-head",
    "c": "gcc-head",
    "js": "nodejs-head",
    "coffee": "coffeescript-head",
    "java": "openjdk-head",
    "hs": "ghc-8.4.2",
    "bash": "bash",
    "cmake": "cmake-head",
    "cr": "crystal-head",
    "exs": "elixir-head",
    "d": "dmd-head",
    "rb": "ruby-head",
    "rs": "rust-head",
    "sql": "sqlite-head",
    "lisp": "clisp-2.49",
    "go": "go-head",
    "fs": "fsharp-head",
    "scala": "scala-2.13.x",
    "swift": "swift-head",
    "ts": "typescript-3.9.5",
    "vim": "vim-head",
    "lua": "lua-5.4.0",
    "nim": "nim-head",
    "php": "php-head",
    "pl": "perl-head",
    "pony": "pony-head",
}
